Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(486)

Unified Diff: src/trusted/validator_mips/ncvalidate.h

Issue 10919162: [MIPS] Implementation of sel_ldr for MIPS architecture. (Closed) Base URL: http://src.chromium.org/native_client/trunk/src/native_client/
Patch Set: Second update per Mark's comments. Created 8 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: src/trusted/validator_mips/ncvalidate.h
diff --git a/src/trusted/validator_arm/ncvalidate.h b/src/trusted/validator_mips/ncvalidate.h
similarity index 51%
copy from src/trusted/validator_arm/ncvalidate.h
copy to src/trusted/validator_mips/ncvalidate.h
index a4a319ac63b700cf621a9d0aab2de72a45f756a0..c866c2026f20a21fe84aec1d2d1f8ef569612a42 100644
--- a/src/trusted/validator_arm/ncvalidate.h
+++ b/src/trusted/validator_mips/ncvalidate.h
@@ -1,12 +1,12 @@
/*
- * Copyright 2009 The Native Client Authors. All rights reserved.
+ * Copyright 2012 The Native Client Authors. All rights reserved.
* Use of this source code is governed by a BSD-style license that can
* be found in the LICENSE file.
- * Copyright 2009, Google Inc.
+ * Copyright 2012, Google Inc.
Mark Seaborn 2012/09/18 03:24:34 You should remove this line and leave the standard
petarj 2012/09/19 17:27:51 Done.
*/
-#ifndef NATIVE_CLIENT_SRC_TRUSTED_VALIDATOR_ARM_V2_NCVALIDATE_H
-#define NATIVE_CLIENT_SRC_TRUSTED_VALIDATOR_ARM_V2_NCVALIDATE_H
+#ifndef NATIVE_CLIENT_SRC_TRUSTED_VALIDATOR_MIPS_NCVALIDATE_H
+#define NATIVE_CLIENT_SRC_TRUSTED_VALIDATOR_MIPS_NCVALIDATE_H
/*
* The C interface to the validator, for use by the sel_ldr (which isn't
@@ -24,13 +24,15 @@ EXTERN_C_BEGIN
/*
* Validates a complete code segment.
* Arguments:
* mbase location of the code in memory right now.
* vbase virtual address where the code will appear at runtime.
* size number of bytes of code provided.
* Result: 0 if validation succeeded, non-zero if we found problems.
*/
-int NCValidateSegment(uint8_t *mbase, uint32_t vbase, size_t size);
+int NCValidateSegment(uint8_t *mbase, uint32_t vbase, size_t size,
+ bool stubout_mode = false);
EXTERN_C_END
-#endif // NATIVE_CLIENT_SRC_TRUSTED_VALIDATOR_ARM_V2_NCVALIDATE_H
+#endif // NATIVE_CLIENT_SRC_TRUSTED_VALIDATOR_MIPS_NCVALIDATE_H

Powered by Google App Engine
This is Rietveld 408576698
@@ -24,13 +24,15 @@ EXTERN_C_BEGIN
* Validates a complete code segment.
* Arguments:
- * mbase location of the code in memory right now.
- * vbase virtual address where the code will appear at runtime.
- * size number of bytes of code provided.
+ * mbase location of the code in memory right now.
+ * vbase virtual address where the code will appear at runtime.
+ * size number of bytes of code provided.
+ * stubout_mode info if the validator should stub-out functions.
* Result: 0 if validation succeeded, non-zero if we found problems.
*/